$NOMOD51
$INCLUDE (C8051F98x.inc)   
HUMI_NOM	EQU 	42			; calibration values
TEMP_NOM	EQU 	294			; T_C + 200
CS_NOM	EQU 	0x87B

humiHigh	EQU	90			; humi % for turning the fan on unconditionally

pressTsch	EQU	0x3F			; press threschold
releaseTsch EQU	0xFC			; release threschold
btDn		EQU	P0.4			; Down button
btUp		EQU	P0.5			; Up button
btLess	EQU	P1.4			; Less button
btMore	EQU	P1.3			; More button
fan		EQU	P1.6			; fan control pin
   
SDA		EQU	P0.6			; LCD interface
SCL		EQU	P0.7
A0		EQU	P1.0
RST		EQU	P1.1
CS		EQU	P1.2
 
	DSEG 	AT 0x20			; data segment in direct addressable space
Status:	DS 1				; status bits 
						; bit0: filling TEMP circular buffer request
						; bit1: filling HUMI circular buffer request
						; bit2: fan status on/off
						; bit3: humi rised even flag
						; bit4: digits font - 0=small, 1=large
						; bit5: countdown run status
						; bit6: erase stats request
						; bit7: humi drop event flag
AUX:		DS 1				; auxilary temporary bit-addressable storage
btState:	DS 1				; button stati
pag:		DS 1				; LCD page #
col: 	 	DS 1				; LCD column #
width: 	DS 1				; LCD bitmap width
height:	DS 1				; LCD bitmap height
cnt:	 	DS 1				; general purpose counter
cntDn:	DS 1				; countdown counter for LCD backlight
showMode:	DS 1

	ORG	0x30
bufTemp: 	DS 16				; circular buffer for temperature (8x 2-byte entries)
tempAve_lo:	DS 1				; storage for temperature average sum
tempAve_hi:	DS 1
temp_lo:	DS 1				; temp value 
temp_hi:	DS 1

	ORG 	0x50
bufHumi:	DS 16				; curcular buffer for humidity
humiAve_lo: DS 1				; storage for humidity average sum
humiAve_hi: DS 1
humiOld:	DS 1				; oldest humi value in circular buffer
humiTarg:	DS 1				; target humi value for turning off the fan
humiCntDn:	DS 2				; countdown counter for running fan 
humiCnt:	DS 1				; period of checking the humi change slope

srDn:		DS 1				; shift regs for buttons debouncing
srUp:		DS 1
srLess:	DS 1
srMore:	DS 1
stateFSM:	DS 1				; FSM state (0: display T/H, 1: backlight, 2: menu)
stateFan:	DS 1				; fan control state

menuMode:	DS 1				; 0: auto, 1: manual
menuPeri:	DS 1				; period of humi slope measurement (sec)
menuRise:	DS 1				; menu settings: sensitivity (%)
menuFall:	DS 1				; hysteresis (%)
menuTime:	DS 1				; fan turn off countdown (min)

menuInd:	DS 1				; primary menu index selector (0 - 4)
menuDir:	DS 1
subMenuDir:	DS 1

	CSEG 	AT 0				; interrupt vectors
	ljmp 	Main  			; reset

	ORG	0x1B				; Timer1 vector
	orl	FLSCL,  #BYPASS		; disable one-shot bypass
	reti

	ORG	0x53				; ADC0 conversion complete vector
	clr	ADC0CN.5			; clear interrupt flag
	reti

	ORG	0xB3				; code section right after the int. vectors
	USING 0          			; specify register bank 

main:       
	anl   PCA0MD, #NOT(0x40) 	; disable the WDT
	mov	SP, #0x7F			; setup stack in indirect storage area

	acall Clock_Setup			; setup peripherals
	acall	Ports_Setup
	acall	Init_LCD
	acall	Timers_Setup
	acall	PCA_Setup			; PWM for LCD backlight brightness
	acall	ADC_Setup			; ADC for measuting TEMP
	acall	CS0_Setup			; CS0 for neasuring HUMI
	acall	System_Init			; init system variables

loop:						; main loop
	anl	FLSCL, #NOT(BYPASS)	; enable one-shop bypass (required for FCLK > 10 MHz)
	mov	PCON,  #0x01		; enter the idle mode 

	acall	Check_Buttons		; check button states
			
	inc	cnt				; increment debounce interval counter				
	mov	A, cnt	
	cjne	A, #25, loop		; as it reaches 25, 1 second has passed
	mov	cnt, #0			; clear counter
	acall	Get_Temp			; recompute temp and humi
	ajmp	loop

;-------------------PROCEDURES-------------------------------------------
Clock_Setup:
	mov	SFRPAGE, #0xF		; switch to SFR page 0xF
	mov	PMU0MD,  #0			; enable POR supply monitor
	mov	SFRPAGE, #0			; switch to default SFR page
	mov 	RSTSRC,  #0x06		; enable MCD and VDD monitor
	anl	OSCICN,  #0x7F		; disable internal precision oscillator
	mov	REG0CN,  #0			; disable precision oscillator bias
	mov	OSCXCN,  #0			; disable external oscillator
	mov	CLKSEL,  #0x04		; select LPO with 1:1 clock divider
	orl	FLSCL,   #BYPASS		; disable one-shot bypass
	mov	A, CLKSEL			; wait for the divider setting to be applied
	jnb	ACC.7, $-2		
	ret

;-----------------------------------------------------------------------
Ports_Setup:
   	mov  	P0MDIN,  #0xFC		; analog input on P0.0, P0.1
    	mov  	P0MDOUT, #0xC0		; open-drain on P0[5:0]
    	mov  	P1MDOUT, #0x67		; open-drain on P1[4:3]
    	mov  	P0SKIP,  #0xFF
    	mov  	P1SKIP,  #0xDF		; assign P1.5 to PCA0
    	mov  	XBR2,    #0x40		; enable Xbar & weak pull-ups
	mov	P0,      #0x3F		; initialize ports
	mov	P1,      #0x1F
    	ret

;------------------------------------------------------------------------
Timers_Setup:
	mov	TMOD,  #0x10		; set mode1 for Timer1
	setb	ET1				; enable Timer1 interrupt
	mov	TCON,  #0x40		; enable Timer1
	ret

;------------------------------------------------------------------------
PCA_Setup:
	mov  	PCA0MD,   #0x02		; use SYSCLK/4
    	mov  	PCA0CPM0, #0xC2		; enable 16-bit PWM
    	mov  	PCA0CPL0, #0x00
    	mov  	PCA0CPH0, #0x01		; set 50% PWM duty cycle
	ret

;------------------------------------------------------------------------
ADC_Setup:
    	mov  	ADC0MX,  #0x01		; ADC input on P0.1
    	mov  	ADC0CF,  #0x11		; set 6.6 MHz clock, gain=1
    	ret

;-----------------------------------------------------------------------
CS0_Setup:
	mov	CS0CN,   #0x80		; enable Capacitive Sense module CS0
	mov	CS0CF,   #0x00		; accumulate no samples
	mov	CS0MD1,  #0x00		; gain = 1x
	mov	CS0MD2,  #0x28		; set 12-bit resolution, discharge time 3 usec 
	mov	CS0MX,   #0x00		; select channel P0.0
	mov	CS0THH,  #0x00		; set-up digital comparator
	mov	CS0THL,  #0xFF		; for waking up the CPU from SUSPEND
	ret

;------------------------------------------------------------------------
System_Init:				; initialization
	mov	A, #0xFF			
	mov	srDn, A			; init shift registers for buttons debouncing
	mov	srUp, A
	mov	srLess, A
	mov	srMore, A
	mov	btState,  #0x0F		; initial buttons state - all up
	mov	stateFSM, #0		; default mode - display TEMP and HUMI
	mov	stateFan, #0
	mov	showMode, #0xFF		; display mode (ON)
	mov	Status,   #3		; request circ buffers initialization

	mov	DPTR, #0x1E00		; EEPROM base address for reading device settings		
	mov	R0,   #menuMode		; RAM address for storing the values
	mov	R1,   #1			; EEPROM offset

si1:	mov	A, R1				; A = EEPROM offset of value
	movc	A, @A+DPTR			; read value from EEPROM
	mov	@R0, A			; save it in RAM
	inc	R0				; update RAM pointer
	inc	R1				; update EEPROM index
	cjne	R1, #6, si1

	mov	humiCnt, menuPeri		; humi change check period
	mov	humiTarg, #0		; fake humi target value
	mov	humiOld,  #100		; init for humi change calculation

	mov	RSTSRC, #2			; enable Vdd monitor as reset source
	setb	EA				; enable interrupts
	ret

;------------------------------------------------------------------------
Get_Temp:
	mov	REF0CN, #0x18           ; enable high-speed ref
	mov	ADC0CN, #0x80		; enable ADC

	mov	A, #67			; 10 usec delay		
	djnz	ACC, $			; 3 cycles

	setb	AD0BUSY 			; start conversion
	nop
	nop
	jb	AD0BUSY, $			; poll BUSY flag	

	mov	ADC0CN, #0			; turn off ADC
	mov	REF0CN, #0			; turn off reference
	mov	R2, ADC0L			; save ADC values in registers
	mov	R3, ADC0H
		
	jnb	Status.0, average_TEMP	; init circ buffer ?
	clr	Status.0			; YES
	mov	R0, #bufTemp		; initialize buffer pointer		
	mov	bufTemp+0, R2		; fill the buffer with
	mov	bufTemp+2, R2		; temp reading (lower byte)
	mov	bufTemp+4, R2
	mov	bufTemp+6, R2
	mov	bufTemp+8, R2
	mov	bufTemp+10, R2
	mov	bufTemp+12, R2
	mov	bufTemp+14, R2
	
	mov	bufTemp+1, R3		; fill the buffer with 
	mov	bufTemp+3, R3		; temp reading (upper byte)
	mov	bufTemp+5, R3
	mov	bufTemp+7, R3
	mov	bufTemp+9, R3
	mov	bufTemp+11, R3
	mov	bufTemp+13, R3
	mov	bufTemp+15, R3	
	
	mov	A, R2
	mov	B, #8				; compose the average sum by
	mul	AB				; multilpying current temp by 8
	mov	tempAve_lo, A
	mov	tempAve_hi, B
	mov	B, #8
	mov	A, ADC0H
	mul	AB
	add	A, tempAve_hi
	mov	tempAve_hi, A
	ajmp	process_TEMP

average_TEMP:
	mov	A, tempAve_lo		; subtract the oldest temp value
	clr	C				; in circular buffer from the 
	subb	A, @R0			; average temp sum
	mov	tempAve_lo, A
	inc	R0				; advance pointer to higher-order byte
	mov	A, tempAve_hi
	subb	A, @R0
	mov	tempAve_hi, A
	
	dec	R0
	mov	@R0, ADC0L			; save new temp in circular buffer
	inc	R0				; update circ buffer pointer
	mov	@R0, ADC0H
	inc	R0
	cjne	R0, #0x40, $+5		; jump over the next instruction
	 mov	R0, #0x30			; take pointer R0 mod 16

	mov	A, tempAve_lo		; update average temp sum
	add	A, ADC0L
	mov	tempAve_lo, A
	mov	A, tempAve_hi
	addc	A, ADC0H
	mov	tempAve_hi, A		; at this point C = 0

	mov	A, tempAve_lo		; average temp sum (div. by 8)	
	rlc	A				; for that we multiply it by 2 
	swap	A				; and swap the nibbles
	anl	A, #0x0F
	mov	R2, A				; R2 contains the lower nibble
	mov	A, tempAve_hi
	rlc	A				; C is not modified since the
	swap	A				; last add
	mov	B, A
	anl	A, #0xF0
	add	A, R2
	mov	R2, A
	mov	A, B				
	anl	A, #0x0F
	mov	R3, A

process_TEMP:
	mov	B, #165			; multiply ADC by 165 (2 bytes x 1 byte)
	mov	A, R2
	mul	AB
	mov	R2, B
	mov	B, #165
	mov	A, R3
	mul	AB
	add	A, R2				; A = lower byte, B = higher byte
	mov	R2, A
 	mov	temp_lo, A
      mov  	A, B
      addc	A,  #0
	mov	R3, A				; R3:R2 = ADC_temp * 165 / 256
 	mov	temp_hi, A

	mov	A, R2				; subtract 50*4-2 = 198 and round off
;	add	A, #0x3A			; 198 = 0xFF3A
	add	A, #0x35			; sensor correction
	mov	R2, A
	mov	A, R3
	addc	A, #0xFF
	mov	R3, A				; R3:R2 = ADC_temp * 165 / 256 - 200

	mov	C, ACC.7			; divide R3:R2 by 4 (signed) 
	rrc	A
	mov	R3, A
	mov	A, R2
	rrc	A
	mov	R2, A
	mov	A, R3
	mov	C, ACC.7
	rrc	A
	mov	R3, A
	mov	A, R2
	rrc	A				
	mov	R2, A				; R3:R2 = ADC_temp * 165 / 1024 - 50

	mov	A, R3				; check computed data range	
	jnb	ACC.7, $+7			; if R3:R2 < 0, set R2=0
	mov	R2, #0
	sjmp	display_TEMP		

	clr	C				; if R3:R2 > 99, set R2=99 
	mov	A, R2
	subb	A, #100
	mov	A, R3
	subb	A, #0
	jc	display_TEMP
	mov	R2, #99			
	
display_TEMP:				
	mov	A, stateFSM			; do not display values in menu mode 2
	add	A, #-2
	jz	get_Humi
	mov	col, #69			; starting column for TEMP
	mov	A, R2				; display value in R2
	acall	Display_Number

;-----------------------------------------------------------------------
get_Humi:
	setb	CS0BUSY			; start conversion
	nop
	nop
	jb	CS0BUSY, $			; wait for the end of conversion

	mov	A, CS0DL			; shift CS value 4 bits to the right 
	swap	A				; needed for 12-bit CS0 resolution
	anl	A, #0x0F
	mov	R2, A				; R2 = lower nibble
	mov	A, CS0DH
	swap	A
	mov	B, A
	anl	A, #0xF0
	orl	A, R2
	mov	R2, A
	mov	A, B
	anl	A, #0x0F
	mov	R3, A				; R3:R2 = shifted CS value

	jnb	Status.1, average_HUMI	; init circ buffer ?
	mov	R1, #bufHumi		; YES - initialize buffer pointer
	mov	bufHumi, R2			; fill the buffer with the
	mov	bufHumi+2, R2		; humi reading (lower byte)
	mov	bufHumi+4, R2
	mov	bufHumi+6, R2
	mov	bufHumi+8, R2
	mov	bufHumi+10, R2
	mov	bufHumi+12, R2
	mov	bufHumi+14, R2

	mov	bufHumi+1, R3		; fill the buffer with the
	mov	bufHumi+3, R3		; humi reading (higher byte)
	mov	bufHumi+5, R3
	mov	bufHumi+7, R3
	mov	bufHumi+9, R3
	mov	bufHumi+11, R3
	mov	bufHumi+13, R3
	mov	bufHumi+15, R3

	mov	A, R2
	mov	B, #8				; compute the average sum by
	mul	AB				; multilpying R3:R2 by 8
	mov	humiAve_lo, A		; value in R3:R2 remains unchanged
	mov	humiAve_hi, B
	mov	B, #8
	mov	A, R3
	mul	AB
	add	A, humiAve_hi
	mov	humiAve_hi, A
	ajmp	process_HUMI

average_HUMI:
	mov	A, humiAve_lo		; subtract the oldest humi value
	clr	C				; in circular buffer from the 
	subb	A, @R1			; average humi sum
	mov	humiAve_lo, A
	inc	R1				; advance pointer to the higher-order byte
	mov	A, humiAve_hi
	subb	A, @R1
	mov	humiAve_hi, A
	
	dec	R1
	mov	@R1, 2			; save new humi in circular buffer
	inc	R1				; update circ buffer pointer
	mov	@R1, 3			; 2 is direct acces to R2 address, 3 is for R3
	inc	R1
	cjne	R1, #0x60, $+5		; jump over the next instruction
	 mov	R1, #0x50			; take pointer R0 mod 16

	mov	A, humiAve_lo		; update average temp sum
	add	A, R2
	mov	humiAve_lo, A
	mov	A, humiAve_hi
	addc	A, R3
	mov	humiAve_hi, A		; at this point C = 0

	mov	A, humiAve_lo		; average humi sum (div. by 8)	
	rlc	A				; for that we multiply it by 2 
	swap	A				; and swap the nibbles
	anl	A, #0x0F
	mov	R2, A				; R2 contains the lower nibble
	mov	A, humiAve_hi
	rlc	A				; C is not modified since the
	swap	A				; last add
	mov	B, A
	anl	A, #0xF0
	add	A, R2
	mov	R2, A
	mov	A, B				
	anl	A, #0x0F
	mov	R3, A				; R3:R2 is averaged humi index

process_HUMI:
	clr	C				; subtract ADC offset
	mov	A, R2
	subb	A, #(CS_NOM MOD 256)
	mov	R2, A
	mov	A, R3
	subb	A, #(CS_NOM / 256)
	mov	AUX, A			; AUX:R2 = adc - a2 (can be negative)

	mov	A, R2				; compute humi*125
	mov	B, #125			; result is at most 16 bits	
	mul	AB
	mov	R2, B
	mov	A, AUX
	mov	B, #125
	mul	AB
	add	A, R2				
	mov	R2, A
	mov	A, B				
      addc	A,  #0			; A:R2 = humi*125 unsigned
	jnb 	AUX.7, $+5			; examine the sign bit
	add	A, #-125			; A:R2 = humi*125 signed
	mov	R3, A				; R3:R2 (adc - a2) / 256

	clr	C
	mov	A, temp_lo			; thermo compensation
	subb	A, #(TEMP_NOM MOD 256)
	mov	temp_lo, A
	mov	A, temp_hi
	subb	A, #(TEMP_NOM / 256)
	mov	AUX, A			; AUX:temp_lo = (T - T_NOM)*4

	mov	A, temp_lo			; compute temp*34 = (T - T_NOM)*136
	mov	B, #34			; result is at most 16 bits	
	mul	AB
	mov	temp_lo, B
	mov	A, AUX
	mov	B, #34
	mul	AB
	add	A, temp_lo			
	mov	temp_lo, A
	mov	A, B				
      addc	A,  #0
	jnb 	AUX.7, $+5			; examine the sign bit
	add	A, #-34	
	mov	temp_hi, A			; temp = (T - T_NOM)*136 / 256 signed

	mov	A, temp_lo			; add temperature correction
	add	A, R2				; to the humidity value
	mov	R2, A
	mov	A, temp_hi
	addc	A, R3
	mov	R3, A	

	mov	A, R2	
	add	A, #2				; rounding off
	mov	R2, A 
	mov	A, R3 
	addc	A, #0				; A:R2 = signed rounded off product / 256	

	mov	C, ACC.7			; get the sign bit
	rrc	A				; A = humi*125/512 (signed)
	mov	R3, A
	mov	A, R2
	rrc	A
	add	A, #HUMI_NOM		; A = RH in %
	mov	R2, A
	mov	A, R3
	addc	A, #0
	mov	R3, A				; R3:R2 = RH in %

	mov	A, R3				; check computed data range	
	jnb	ACC.7, $+7			; if R3:R2 < 0, set R2=0
	mov	R2, #0
	sjmp	check_HUMI_change		

	clr	C				; if R3:R2 > 99, set R2=99 
	mov	A, R2
	subb	A, #100
	mov	A, R3
	subb	A, #0
	jb	ACC.7, check_HUMI_change
	mov	R2, #99	

check_HUMI_change:
	jnb	Status.1, chc1		; first humi measurement after power-up?
	clr	Status.1			; YES - clear filling circ buffer request

	mov 	A, menuMode			; in manual mode only start fan and countdown 
	jnz 	chc0
	setb	fan				; turn fan on
	setb	Status.2			; set fan status flag	
	sjmp	fs11

chc0:	mov	A, R2				; if humi >= 90% at the first measurement
	clr	C				; then start the fan 
	subb	A, #humiHigh
	jnb	ACC.7, fs01			
	
chc1:	mov	A, menuMode			; drop humi rise/drop check in manual mode
	jz	chc4

	djnz	humiCnt, chc4		; time to check humi rise/drop?
	mov	humiCnt, menuPeri		; YES - restore the counter

	mov	A, R2				; check if humiNew >= humiOld+humiSens
	clr	C
	subb	A, humiOld
	clr	C
	subb	A, menuRise
	jb	ACC.7, chc2			
	setb	Status.3			; set event flag

chc2:	mov	A, humiOLD			; check if humiOld >= humiNew+humiFall
	clr	C			
	subb	A, R2
	clr	C
	subb	A, menuFall
	jb	ACC.7, chc3 		
	setb	Status.7			; set event flag

chc3:	mov	humiOld, R2

chc4:	mov	A, stateFan			; main FSM
	cjne	A, #1, $+5 			; state selector
	sjmp	fanState1
	jnc	fanState2

fanState0:					; fan off, monitoring humi changes
	clr	Status.7			; ignore humi drop event
	jnb	Status.3, display_Humi	; HUMI rised up ?
	clr	Status.3			; YES - clear humi rise event flag
	mov	humiTarg, humiOld		; setup target humi value

fs01:	setb	fan				; turn fan on
	setb	Status.2			; set fan status flag
	mov	stateFan, #1		; transfer to state 1
	sjmp	display_Humi

fanState1:					; fan is on, wait for water off
	clr	Status.3			; ignore humi rise event
	jnb	Status.7, display_Humi	; humi dropped down?
	clr	Status.7			; YES - clear humi drop event flag

fs11:	mov	humiCntDn, menuTime	; start countdown 
	mov	humiCntDn+1, #60		; seconds counter for countdown
	setb	Status.5			; set countdown run status
	mov 	stateFan, #2		; transfer to state 2
	sjmp	display_Humi

fanState2:					; fan is on, wait for cntdown or target humi
	clr	Status.7			; ignore humi drop event
	jnb	Status.3, fs21		; humi raised up again?
	mov	humiCntDn, menuTime	; YES - reset countdown period 
	mov	humiCntDn+1, #60		; and the seconds counter for countdown
	clr	Status.3			; clear rise-up status	

fs21:	mov	A, humiTarg			; check if current humi <= humiTarg 
	clr	C				
	subb	A, R2
	jnb	ACC.7, fs23			; target humi is reached 

fs22:	djnz	humiCntDn+1, display_HUMI	; decrement seconds counter
	mov	humiCntDn+1, #60		; restore seconds counter
	djnz	humiCntDn, display_HUMI	; decrement minutes counter
	
fs23: clr	fan				; turn fan off 
	clr	Status.2			; clear fan status
	clr	Status.5			; clear cntdown run status
	setb	Status.6			; request to erase stats data
	mov	stateFan, #0		; back to idling in state 0

display_HUMI:
	mov	A, stateFSM			; display humi only if not in menu mode
	cjne	A, #2, $+4
	ret
	mov	col, #0			; starting LCD column for the humi value
	mov	A, R2				; display value in R2
	acall	Display_Number

	jnb	Status.2, $+5		; if fan is running
	acall	Display_Stats		;   display the target humi and countdown
	jnb	Status.6, $+5		; if erase stats is requested
	acall	Erase_Stats			;   do it
	ret
	
;------------------------------------------------------------------------
Light_OFF:					
	mov	stateFSM, #0		; turn off LCD backlight on timeout
	mov	XBR1,	   #0x00		; route port to output pin
	mov  	PCA0CN,  #0x00		; disable PCA channel 0
	ret	

;------------------------------------------------------------------------
Display_Stats:				; display target humi and countdown 
	setb	Status.4			; set tiny font
	mov	A, menuMode			; do not display target temp 
	jz	ds1				;    ... in manual mode
	mov	A, humiTarg			; and if taget humi = 0
	jz	ds1

	mov	col, #45			; display position for target humi
	mov	A, humiTarg
	acall	Display_Number

ds1:	jnb	Status.5, ds2		; display countdown only if it is running
	mov	col, #116
	mov	A, humiCntDn
	acall	Display_Number

ds2:	clr	Status.4			; back to default font
	ret

;------------------------------------------------------------------------
Erase_Stats:
	mov	pag,    #0			; erase target humi and timeout
	mov	width,  #12
	mov	height, #1
	mov	col,    #45
	mov	showMode, #0		; erase LCD mode
	mov	DPTR,   #Small_Font
	acall	Display_Symbol
	mov	col,    #116
	acall	Display_Symbol
	mov	showMode, #0xFF		; back to show mode
	clr	Status.6			; clear request flag
	ret

;========================================================================
$INCLUDE (lcd.asm)
$INCLUDE (menu.asm)
$INCLUDE (fonts.asm)
;========================================================================
	ORG 0x1E00				; lock byte page (EEPROM area)
	DB	0xFF				; unused 
	DB	1				; menuMode: default menu mode (auto)
	DB	5				; menuPeri: humi slope measurement period (sec)
	DB	3				; menuRise: humi rising rate for turning fan on
	DB	1				; menuFall: humi falling rate for turning fan off
	DB	20				; menuTime: default fan off timeout (min)
	
END