Display_Number:				; show a 2-digit number in ACC 
	mov	B, #10
	div	AB				; A = 1st digit B = 2nd digit
	push	B
	jnz	$+5
	mov	showMode, #0		; do not display the 1st symbol if it is 0
	acall	Set_Font_PTR		; set DPTR pointer to the digit data
	acall	Display_Symbol		; display the 1st digit
	mov	A, col
	add	A, width
	add	A, #2				; column number for the 2nd digit
	mov	col, A
	pop	ACC				; display 2nd digit
	mov	showMode, #0xFF		; display mode
	acall	Set_Font_PTR		; set DPTR pointer to the digit data
	acall	Display_Symbol
	ret

;------------------------------------------------------------------------
Display_Bitmap:				; display 2-dim bitmap pointed by DPTR
	clr	A				; width offset in bitmap
	movc	A, @A+DPTR			; get bitmap width
	mov	width, A			; save it
	mov	A, #1				; height offset in bitmap (# of pages)
	movc	A, @A+DPTR
	mov	height, A
	mov	R5, #2			; bitmap data offset
	sjmp	$+4

Display_Symbol:				; col, pag, width, height and DPTR must be set
	mov	R5, #0			; symbol bitmap data offset
	push	height
	mov	R7, pag			; initial page number
dbm1:
	mov	A, R7
	orl	A, #0xB0					
	acall	Command_LCD			; set page

	mov	A, col
	swap	A
	anl	A, #0x0F
	orl	A, #0x10			; set column address (MSB)
	acall	Command_LCD
	mov	A, col
	anl	A, #0x0F			; set column address (LSB)
	acall	Command_LCD
			
	mov	R6, width			; loop over bitmap columns
dbm2:
	mov	A, R5
	inc	R5
	movc	A, @A+DPTR
	anl	A, showMode			; display or erase
	acall	Write_LCD		
	djnz	R6, dbm2
	dec	R7
	dec	height
	mov	A, height
	jnz	dbm1
	pop	height
	ret

;-------------------LCD INTERFACE----------------------------------------
Command_LCD:				; write a command in ACC to LCD
	clr	CS				; chip select
	clr	A0				; clear command/data selector
	sjmp	$+6

Write_LCD:
	clr	CS				; chip select
	setb	A0				; set command/data selector
	mov	R4, #8			; loop counter
wl_loop:
	rlc	A				; shift out msb into CY
	mov	SDA, C			; copy ACC bit to port
	setb	SCL				; clock up
	sjmp	$+2				; 2-cycle delay
	clr	SCL				; clock down
	djnz	R4, wl_loop			; loop back
	rlc	A				; (optional) restore ACC
	setb	CS
	ret

Init_LCD:
	acall	Delay_1ms
	setb	RST				; move LCD out of reset
	acall	Delay_1ms
	clr	SCL				; make sure that clock is down

	mov	A, #0xAC			; sleep mode ON (2-byte command)
	acall	Command_LCD	
	mov	A, #0x00			; set sleep mode
	acall	Command_LCD
	mov	A, #0xAF			; display OFF
	acall	Command_LCD
	mov	A, #0xA5			; display all points
	acall	Command_LCD

	mov	A, #0xA2			; set LCD bias 1/9
	acall	Command_LCD	
	mov	A, #0xA0			; set non-reversed display
	acall	Command_LCD
	mov	A, #0xC0			; set normal direction
	acall	Command_LCD
	mov	A, #0x20			; set V0 resisors Ra/Rb ratio
	acall	Command_LCD
	mov	A, #0x81			; set V0 out voltage
	acall	Command_LCD
	mov	A, #0x37			; second byte of set volume command
	acall	Command_LCD
	mov	A, #0x2F			; set internal power mode (all on)
	acall	Command_LCD

	mov	A, #0xA4			; display all points OFF
	acall	Command_LCD
	mov	A, #0xAC			; sleep mode OFF (2-byte command)
	acall	Command_LCD	
	mov	A, #0x01			; set normal mode
	acall	Command_LCD

	mov	A, #0x40			; reset start line # to 0
	acall	Command_LCD
	mov	A, #0xAF			; display ON
	acall	Command_LCD

Default_Screen:
	acall	Clear_LCD
	mov	pag, #3			; page #
	mov	height, #2			; symbol height (in bytes)
	mov	col, #43			; column #
	mov	width, #13			; symbol % width
	mov	DPTR, #Percent		; symbol pointer
	acall	Display_Symbol

	mov	col, #111			; column #
	mov	width, #17			; symbol C width
	mov	DPTR, #Deg_C		; symbol pointer
	acall	Display_Symbol
	ret

Delay_1ms:
	mov	R5, #100			; 1 msec power-up delay
del_1ms:					
	mov	A, #67
	djnz	ACC, $			; 3*57=201 cycles delay (10 mksec)
	djnz	R5, del_1ms
	ret

;------------------------------------------------------------------------
Clear_LCD:
	mov	R7, #4			; set page 3
next_page:
	mov	A, R7
	dec	A
	orl	A, #0xB0			; set page command
	acall	Command_LCD

	mov	A, #0x10			; set column address (MSN)
	acall	Command_LCD
	mov	A, #0
	acall	Command_LCD	

	mov	R6, #128			; # of columns
next_col:
	mov	A, #0x00
	acall	Write_LCD
	djnz	R6, next_col 
	djnz	R7, next_page
	ret

;------------------------------------------------------------------------
Clear_Menu:
	mov	R7, #2			; set page 2
cm1:
	mov	A, R7
	orl	A, #0xB0			; set page command
	acall	Command_LCD

	mov	A, #0x10			; set column address (MSN)
	acall	Command_LCD
	mov	A, #0
	acall	Command_LCD	

	mov	R6, #128			; # of columns
cm2:
	mov	A, #0x00
	acall	Write_LCD
	djnz	R6, cm2 
	djnz	R7, cm1
	ret


