Show_Menu:
	mov	height, #1			; navigation symbol height (in bytes)
	acall	Clear_LCD
	mov	pag,   #3			; arrow up
	mov	col,   #0
	mov   width, #9
	mov	DPTR,  #Arrow_up
	acall	Display_Symbol

	mov	col,   #120			; the "+" symbol
	mov   width, #8
	mov	DPTR,  #Plus
	acall	Display_Symbol

	mov	pag,   #0			; arrow down
	mov	col,   #0
	mov   width, #9
	mov	DPTR,  #Arrow_down
	acall	Display_Symbol

	mov	col,   #120			; the "-" symbol
	mov   width, #8
	mov	DPTR,  #Minus
	acall	Display_Symbol

	mov	pag, #2
	mov	col, #9
	mov	DPTR, #Mode
	acall	Display_Bitmap
	mov	col, #77
	mov	DPTR, #auto
	acall	Display_Bitmap

	mov	menuInd, #0
	ret

;------------------------------------------------------------------------
Check_Buttons:				; check button states and update		
	mov	C, btDn			;   the btState register
	mov	A, srDn			; debouncing the Down button
	rrc	A
	mov	srDn, A

	clr	C
     	jnb  	btState.0, deb0    	; old state = "up" ?	
	subb	A, #(pressTsch+1)		; YES: set C=1 if SF <= pressTsch
	mov	btState.4, C		; if so, set the button pressed flag
	sjmp	$+4
deb0:	subb	A, #releaseTsch		; C=0 if SR >= releaseTsch

debUp:	
	cpl	C
     	mov  	btState.0, C            ; update button state
     
	mov	C, btUp			; debouncing the Up button
	mov	A, srUp
	rrc	A
	mov	srUp, A

	clr	C
     	jnb  	btState.1, deb1    	; old state = "up" ?	
	subb	A, #(pressTsch+1)		; YES: set C=1 if SF <= pressTsch
	mov	btState.5, C		; if so, set the button pressed flag
	sjmp	$+4
deb1:	subb	A, #releaseTsch		; C=0 if SR >= releaseTsch

debLess:
	cpl	C
     	mov  	btState.1, C            ; update button state	

	mov	C, btLess			; debouncing the Less button
	mov	A, srLess
	rrc	A
	mov	srLess, A

	clr	C
     	jnb  	btState.2, deb2    	; old state = "up" ?	
	subb	A, #(pressTsch+1)		; YES: set C=1 if SF <= pressTsch
	mov	btState.6, C		; if so, set the button pressed flag
	sjmp	$+4
deb2:	subb	A, #releaseTsch		; C=0 if SR >= releaseTsch

debMore:
	cpl	C
     	mov  	btState.2, C            ; update button state

	mov	C, btMore			; debouncing the More button
	mov	A, srMore
	rrc	A
	mov	srMore, A

	clr	C
     	jnb  	btState.3, deb3    	; old state = "up" ?	
	subb	A, #(pressTsch+1)		; YES: set C=1 if SF <= pressTsch
	mov	btState.7, C		; if so, set the button pressed flag
	sjmp	$+4
deb3:	subb	A, #releaseTsch		; C=0 if SR >= releaseTsch

	cpl	C
     	mov  	btState.3, C            ; update button state

;------------------------------------------------------------------------
FSM:						; MENU FINITE STATE MACHINE
	mov	A, stateFSM	
	cjne	A, #1, $+5 
	sjmp	state1
	jnc	state2

state0:					; display temp/humi
	mov	A, btState
	anl	A, #0xF0			; chop off button stati
	jnz	$+3				; some button is just pressed
	ret					; no button is pressed - return

	mov	stateFSM, #1		; turn on LCD backlight
	mov	cntDn, #125			; countdown for 125/25=5 seconds
	mov  	PCA0CN,  #0x40		; enable PCA channel 0	
	mov	XBR1,	   #0x01		; route CEX0 to output pin

clearFlags:
	mov	A, btState
	anl	A, #0x0F			; clear button flags
	mov	btState, A
	ret

state1:					; waiting for countdown or button press
	mov	A, btState
	anl	A, #0xF0			; chop off button stati
	jnz	s1bt				; some button is just pressed

	djnz	cntDn, $+5			; no button is pressed - do countdown
	acall	Light_OFF			; turn off LCD backlight
 	ret

s1bt:
	mov	stateFSM, #2		; enter menu state
	acall	Show_Menu
	sjmp 	clearFlags
	
state2:					; menu mode
	mov	A, btState
	anl	A, #0xF0			; chop off button stati
	jnz	$+3				; some button is just pressed
	ret					; no button is pressed - return

	mov	submenuDir, #0
downBut:					; down button processing
	jnb	btState.4, upBut
	mov	menuDir, #1
	sjmp	Update_Menu

upBut:					; up button processing
	jnb	btState.5, lessBut
	mov	menuDir, #-1
	sjmp	Update_Menu	

lessBut:					; less button processing
	jnb	btState.6, moreBut
	mov	submenuDir, #-1
	sjmp	Update_Sub_Menu	

moreBut:					; more button processing
	jnb	btState.7, clearFlags
	mov	submenuDir, #1
	sjmp	Update_Sub_Menu

;------------------------------------------------------------------------
Update_Menu:
	mov	A, menuInd			; update menu index modulo 6
	add	A, menuDir
	cjne	A, #0xFF, $+5
	mov 	A, #5
	cjne	A, #6, $+4
	clr 	A
	mov	menuInd, A

	call	Clear_Menu	
	call	Get_Menu_Ptr
	mov	col, #9
	mov	pag, #2
	call	display_Bitmap

Update_Sub_Menu:			
	mov	A, menuInd			; display menu choice
	cjne	A, #0, mi0			; processing Mode (man/auto)
	mov	A, menuMode
	add	A, submenuDir
	anl	A, #1
	mov	menuMode, A
mi0a: mov	col, #77
	jnb	ACC.0, mi0b
	mov	DPTR, #auto
	sjmp	$+5
mi0b:	mov	DPTR, #man
	acall	Display_Bitmap
	ajmp	clearFlags	

mi0:	mov	col, #99
	cjne	A, #1, mi1			; processing Period
	mov	A, menuPeri
	add	A, submenuDir
	cjne	A, #1, $+5
	mov	A, #2				; lower bound for period
	cjne	A, #31, $+5			
	mov	A, #30			; upper bound for period
	mov	menuPeri, A
	acall	Display_Number
	ajmp	clearFlags

mi1:	cjne	A, #2, mi2			; processing Rise rate 1
	mov	A, menuRise
	add	A, submenuDir
	cjne	A, #0, $+5
	mov	A, #1				; lower bound for rise
	cjne	A, #10, $+5			
	mov	A, #9				; upper bound for rise
	mov	menuRise, A
	acall	Display_Number
	ajmp	clearFlags

mi2:	cjne	A, #3, mi3			; processing Fall rate
	mov	A, menuFall
	add	A, submenuDir
	cjne	A, #0, $+5
	mov	A, #1				; lower bound for fall
	cjne	A, #10, $+5			
	mov	A, #9				; upper bound for fall
	mov	menuFall, A
	acall	Display_Number
	ajmp	clearFlags

mi3:	cjne	A, #4, mi4			; processing Timer
	mov	A, menuTime
	add	A, submenuDir
	cjne	A, #0, $+5
	mov	A, #1				; lower bound for timer
	cjne	A, #61, $+5			
	mov	A, #60			; upper bound for timer
	mov	menuTime, A
	acall	Display_Number
	ajmp	clearFlags

mi4:	cjne	A, #5, mi5			; processing Exit
	mov	A, submenuDir
	jz	mi5

	clr	EA				; start saving menu settings
	mov	DPTR,  #0x1E00		; EEPROM base address
	mov	PSCTL, #3			; enable flash write and erase
	push	0				; save R0
	mov	R0, #menuMode-1		; init RAM pointer	

sfl:	mov	FLKEY, #0xA5		; 1st key code
	mov	FLKEY, #0xF1		; 2nd key code
	mov	A, @R0			; get value from RAM
	movx	@DPTR, A			; write it to flash
	inc	R0				; update RAM pointer 
	inc	DPL				; update flash pointer
	mov	PSCTL, #1			; enable flash write (1st write erases the page)
	cjne	R0, #menuTime+1, sfl	; check for all values being saved

	mov	PSCTL, #0			; disable flash write
	pop	0				; restore R0
	setb	EA				; re-enable interrupts

mi4a:	mov	stateFSM, #0		; back to default state
	acall	Light_OFF
	acall	Default_Screen

mi5:	ajmp	clearFlags

;------------------------------------------------------------------------
Get_Menu_Ptr:
	mov	A, menuInd
	rl	A
	rl	A
	mov	DPTR, #Menu_Tab
	jmp	@A+DPTR
Menu_Tab:
	mov	DPTR, #Mode
	ret
	mov	DPTR, #Period
	ret
	mov	DPTR, #Rise
	ret
	mov	DPTR, #Fall
	ret
	mov	DPTR, #Timer
	ret
	mov	DPTR, #Exit
	ret
